@@ -25,22 +25,6 @@
 #include <gio/gio.h>
 #include <pk-backend.h>
 
-/* libalpm up to and including version 9.0.0 (pacman 4.2.0) lack proper
- * versioning. A patch has been proposed, though:
- * https://lists.archlinux.org/pipermail/pacman-dev/2014-December/019759.html
- *
- * If ALPM_VERSION_NUMBER is *not* defined we test for
- * ALPM_EVENT_PACKAGE_OPERATION_START, which is libalpm >= 9.0.0 only and
- * define ALPM_VERSION_NUMBER on our own. */
-
-#ifndef ALPM_VERSION_NUMBER
-#	ifndef ALPM_EVENT_PACKAGE_OPERATION_START
-#		define	ALPM_VERSION_NUMBER	0x080200
-#	else
-#		define	ALPM_VERSION_NUMBER	0x090000
-#	endif
-#endif
-
 typedef struct {
 	gsize		environment_initialized;
 	alpm_db_t	*localdb;
