@@ -2,6 +2,7 @@
  *
  * Copyright (c) 1999 Patrick Cole <z@amused.net>
  *           (c) 2002 Synaptic development team
+ *           (c) 2016 Daniel Nicoletti <dantti12@gmail.com>
  *
  * Author: Patrick Cole <z@amused.net>
  *         Michael Vogt <mvo@debian.org>
@@ -36,18 +37,18 @@
 #include <algorithm>
 #include <fstream>
 
+#include "apt-utils.h"
+
 #include "config.h"
 
 SourcesList::~SourcesList()
 {
-    for (list<SourceRecord *>::iterator it = SourceRecords.begin();
-         it != SourceRecords.end(); ++it) {
-        delete *it;
+    for (SourceRecord *sr : SourceRecords) {
+        delete sr;
     }
 
-    for (list<VendorRecord *>::iterator it = VendorRecords.begin();
-         it != VendorRecords.end(); ++it) {
-        delete *it;
+    for (VendorRecord *vr : VendorRecords) {
+        delete vr;
     }
 }
 
@@ -221,8 +222,8 @@ bool SourcesList::ReadSourceDir(string Dir)
     sort(List.begin(), List.end());
 
     // Read the files
-    for (vector<string>::const_iterator I = List.begin(); I != List.end(); ++I) {
-        if (ReadSourcePart(*I) == false) {
+    for (const string &sourcePart : List) {
+        if (ReadSourcePart(sourcePart) == false) {
             return false;
         }
     }
@@ -311,48 +312,45 @@ void SourcesList::SwapSources( SourceRecord *&rec_one, SourceRecord *&rec_two )
 bool SourcesList::UpdateSources()
 {
     list<string> filenames;
-    for (list<SourceRecord *>::iterator it = SourceRecords.begin();
-         it != SourceRecords.end(); ++it) {
-        if ((*it)->SourceFile == "") {
+    for (SourceRecord *sr : SourceRecords) {
+        if (sr->SourceFile == "") {
             continue;
         }
-        filenames.push_front((*it)->SourceFile);
+        filenames.push_front(sr->SourceFile);
     }
     filenames.sort();
     filenames.unique();
 
-    for (list<string>::iterator fi = filenames.begin();
-         fi != filenames.end(); fi++) {
-        ofstream ofs((*fi).c_str(), ios::out);
+    for (const string &filename : filenames) {
+        ofstream ofs(filename.c_str(), ios::out);
         if (!ofs != 0) {
             return false;
         }
 
-        for (list<SourceRecord *>::iterator it = SourceRecords.begin();
-             it != SourceRecords.end(); it++) {
-            if ((*fi) != (*it)->SourceFile) {
+        for (SourceRecord *sr : SourceRecords) {
+            if (filename != sr->SourceFile) {
                 continue;
             }
 
             string S;
-            if (((*it)->Type & Comment) != 0) {
-                S = (*it)->Comment;
-            } else if ((*it)->URI.empty() || (*it)->Dist.empty()) {
+            if ((sr->Type & Comment) != 0) {
+                S = sr->Comment;
+            } else if (sr->URI.empty() || sr->Dist.empty()) {
                 continue;
             } else {
-                if (((*it)->Type & Disabled) != 0)
+                if ((sr->Type & Disabled) != 0)
                     S = "# ";
 
-                S += (*it)->GetType() + " ";
+                S += sr->GetType() + " ";
 
-                if ((*it)->VendorID.empty() == false)
-                    S += "[" + (*it)->VendorID + "] ";
+                if (sr->VendorID.empty() == false)
+                    S += "[" + sr->VendorID + "] ";
 
-                S += (*it)->URI + " ";
-                S += (*it)->Dist + " ";
+                S += sr->URI + " ";
+                S += sr->Dist + " ";
 
-                for (unsigned int J = 0; J < (*it)->NumSections; ++J) {
-                    S += (*it)->Sections[J] + " ";
+                for (unsigned int J = 0; J < sr->NumSections; ++J) {
+                    S += sr->Sections[J] + " ";
                 }
             }
             ofs << S << endl;
@@ -433,6 +431,68 @@ bool SourcesList::SourceRecord::SetURI(string S)
     return true;
 }
 
+string SourcesList::SourceRecord::joinedSections()
+{
+    string ret;
+    for (unsigned int i = 0; i < NumSections; ++i) {
+        ret += Sections[i];
+        if (i + 1 < NumSections) {
+            ret += " ";
+        }
+    }
+    return ret;
+}
+
+string SourcesList::SourceRecord::niceName()
+{
+    string ret;
+    if (starts_with(URI, "cdrom")) {
+        ret = "Disc ";
+    }
+
+    // Make distribution camel case
+    std::locale loc;
+    string dist = Dist;
+    dist[0] = std::toupper(dist[0], loc);
+
+    // Replace - or / by by a space
+    std::size_t found = dist.find_first_of("-/");
+    while (found != std::string::npos) {
+        dist[found] = ' ';
+        found = dist.find_first_of("-/", found + 1);
+    }
+    ret += dist;
+
+    // Append sections: main contrib non-free
+    if (NumSections) {
+        ret += " (" + joinedSections() + ")";
+    }
+
+    return ret;
+}
+
+string SourcesList::SourceRecord::repoId()
+{
+    string ret;
+    ret = SourceFile;
+    ret += ":" + GetType();
+    ret += VendorID + " ";
+    ret += URI + " ";
+    ret += Dist + " ";
+    ret += joinedSections();
+    return ret;
+}
+
+bool SourcesList::SourceRecord::hasSection(const char *component)
+{
+    for (unsigned int i = 0; i < NumSections; ++i) {
+        if (Sections[i].compare(component) == 0) {
+            return true;
+        }
+    }
+    return false;
+}
+
 SourcesList::SourceRecord &SourcesList::SourceRecord::operator=(const SourceRecord &rhs)
 {
     // Needed for a proper deep copy of the record; uses the string operator= to properly copy the strings
@@ -471,9 +531,8 @@ bool SourcesList::ReadVendors()
         }
     }
 
-    for (list<VendorRecord *>::const_iterator I = VendorRecords.begin();
-         I != VendorRecords.end(); ++I) {
-        delete *I;
+    for (VendorRecord *vr : VendorRecords) {
+        delete vr;
     }
     VendorRecords.clear();
 
@@ -530,11 +589,10 @@ bool SourcesList::UpdateVendors()
         return false;
     }
 
-    for (list<VendorRecord *>::iterator it = VendorRecords.begin();
-         it != VendorRecords.end(); ++it) {
-        ofs << "simple-key \"" << (*it)->VendorID << "\" {" << endl;
-        ofs << "\tFingerPrint \"" << (*it)->FingerPrint << "\";" << endl;
-        ofs << "\tName \"" << (*it)->Description << "\";" << endl;
+    for (VendorRecord *vr : VendorRecords) {
+        ofs << "simple-key \"" << vr->VendorID << "\" {" << endl;
+        ofs << "\tFingerPrint \"" << vr->FingerPrint << "\";" << endl;
+        ofs << "\tName \"" << vr->Description << "\";" << endl;
         ofs << "}" << endl;
     }
 
