@@ -815,6 +815,10 @@ main (int argc, char *argv[])
 	 * the style of bash itself -- apologies */
 	g_printerr ("%s: %s: %s...\n", shell, argv[1], _("command not found"));
 
+	/* ignore one char mistakes */
+	if (len < 2)
+		goto out;
+
 	/* user is not allowing CNF to do anything useful */
 	if (!config->software_source_search &&
 	    !config->similar_name_search) {
@@ -872,6 +876,7 @@ main (int argc, char *argv[])
 
 			/* TRANSLATORS: ask the user to choose a file to run */
 			i = pk_console_get_number (_("Please choose a command to run"), array->len);
+			g_assert (i < array->len);
 
 			/* run command */
 			possible = g_ptr_array_index (array, i);
@@ -943,6 +948,7 @@ main (int argc, char *argv[])
 					g_printerr ("%s\n", _("User aborted selection"));
 					goto out;
 				}
+				g_assert (i < len);
 
 				/* run command */
 				ret = pk_cnf_install_package_id (package_ids[i - 1]);
