@@ -1731,6 +1731,66 @@ pk_client_repo_remove (PkClient *client,
 	return results;
 }
 
+/**
+ * pk_client_upgrade_system:
+ * @distro_id: a distro ID such as "fedora-14"
+ * @upgrade_kind: a #PkUpgradeKindEnum such as %PK_UPGRADE_KIND_ENUM_COMPLETE
+ * @cancellable: a #GCancellable or %NULL
+ * @progress_callback: (scope call): the function to run when the progress changes
+ * @progress_user_data: data to pass to @progress_callback
+ * @error: the #GError to store any failure, or %NULL
+ *
+ * This transaction will upgrade the distro to the next version, which may
+ * involve just downloading the installer and setting up the boot device,
+ * or may involve doing an on-line upgrade.
+ *
+ * The backend will decide what is best to do.
+ *
+ * Warning: this function is synchronous, and may block. Do not use it in GUI
+ * applications.
+ *
+ * Return value: (transfer full): a %PkResults object, or NULL for error
+ *
+ * Since: 1.0.10
+ **/
+PkResults *
+pk_client_upgrade_system (PkClient *client, PkBitfield transaction_flags,
+			  const gchar *distro_id, PkUpgradeKindEnum upgrade_kind,
+			  GCancellable *cancellable,
+			  PkProgressCallback progress_callback, gpointer progress_user_data, GError **error)
+{
+	PkClientHelper helper;
+	PkResults *results;
+
+	g_return_val_if_fail (PK_IS_CLIENT (client), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	/* create temp object */
+	memset (&helper, 0, sizeof (PkClientHelper));
+	helper.context = g_main_context_new ();
+	helper.loop = g_main_loop_new (helper.context, FALSE);
+	helper.error = error;
+
+	g_main_context_push_thread_default (helper.context);
+
+	/* run async method */
+	pk_client_upgrade_system_async (client, transaction_flags, distro_id, upgrade_kind,
+					cancellable, progress_callback, progress_user_data,
+					(GAsyncReadyCallback) pk_client_generic_finish_sync, &helper);
+
+	g_main_loop_run (helper.loop);
+
+	results = helper.results;
+
+	g_main_context_pop_thread_default (helper.context);
+
+	/* free temp object */
+	g_main_loop_unref (helper.loop);
+	g_main_context_unref (helper.context);
+
+	return results;
+}
+
 /**
  * pk_client_repair_system:
  * @transaction_flags: if only trusted packages should be installed
