@@ -229,7 +229,7 @@ pk_get_distro_id_machine_type (void)
  * Internal helper to parse os-release
  **/
 static gboolean
-pk_parse_os_release (gchar **id, gchar **version_id, GError **error)
+pk_parse_os_release (gchar **id, gchar **name, gchar **version_id, GError **error)
 {
 	const gchar *filename = "/etc/os-release";
 	gboolean ret;
@@ -258,6 +258,11 @@ pk_parse_os_release (gchar **id, gchar **version_id, GError **error)
 		if (*id == NULL)
 			return FALSE;
 	}
+	if (name != NULL) {
+		*name = g_key_file_get_string (key_file, "os-release", "NAME", error);
+		if (*name == NULL)
+			return FALSE;
+	}
 	if (version_id != NULL) {
 		*version_id = g_key_file_get_string (key_file, "os-release", "VERSION_ID", error);
 		if (*version_id == NULL)
@@ -277,21 +282,39 @@ pk_get_distro_id (void)
 	gboolean ret;
 	g_autoptr(GError) error = NULL;
 	g_autofree gchar *arch = NULL;
-	g_autofree gchar *name = NULL;
+	g_autofree gchar *id = NULL;
 	g_autofree gchar *version = NULL;
 
 	/* we don't want distro specific results in 'make check' */
 	if (g_getenv ("PK_SELF_TEST") != NULL)
 		return g_strdup ("selftest;11.91;i686");
 
-	ret = pk_parse_os_release (&name, &version, &error);
+	ret = pk_parse_os_release (&id, NULL, &version, &error);
 	if (!ret) {
 		g_warning ("failed to load os-release: %s", error->message);
 		return NULL;
 	}
 
 	arch = pk_get_distro_id_machine_type ();
-	return g_strdup_printf ("%s;%s;%s", name, version, arch);
+	return g_strdup_printf ("%s;%s;%s", id, version, arch);
+}
+
+/**
+ * pk_get_distro_name:
+ *
+ * Return value: the distro name, e.g. "Fedora", as specified by NAME in /etc/os-release
+ **/
+gchar *
+pk_get_distro_name (GError **error)
+{
+	gboolean ret;
+	gchar *name = NULL;
+
+	ret = pk_parse_os_release (NULL, &name, NULL, error);
+	if (!ret)
+		return NULL;
+
+	return name;
 }
 
 /**
@@ -305,7 +328,7 @@ pk_get_distro_version_id (GError **error)
 	gboolean ret;
 	gchar *version_id = NULL;
 
-	ret = pk_parse_os_release (NULL, &version_id, error);
+	ret = pk_parse_os_release (NULL, NULL, &version_id, error);
 	if (!ret)
 		return NULL;
 
