@@ -172,6 +172,19 @@ pk_progress_set_package_id (PkProgress *progress, const gchar *package_id)
 	return TRUE;
 }
 
+/**
+ * pk_progress_get_package_id:
+ * @progress: a valid #PkProgress instance
+ *
+ * Since: 1.0.12
+ **/
+const gchar *
+pk_progress_get_package_id (PkProgress *progress)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), NULL);
+	return progress->priv->package_id;
+}
+
 /**
  * pk_progress_set_item_progress:
  * @progress: a valid #PkProgress instance
@@ -196,6 +209,21 @@ pk_progress_set_item_progress (PkProgress *progress,
 	return TRUE;
 }
 
+/**
+ * pk_progress_get_item_progress:
+ * @progress: a valid #PkProgress instance
+ *
+ * Return value: (transfer none):
+ *
+ * Since: 1.0.12
+ **/
+PkItemProgress *
+pk_progress_get_item_progress (PkProgress *progress)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), NULL);
+	return progress->priv->item_progress;
+}
+
 /**
  * pk_progress_set_transaction_id:
  * @progress: a valid #PkProgress instance
@@ -219,8 +247,22 @@ pk_progress_set_transaction_id (PkProgress *progress, const gchar *transaction_i
 	return TRUE;
 }
 
+/**
+ * pk_progress_get_transaction_id:
+ * @progress: a valid #PkProgress instance
+ *
+ * Since: 1.0.12
+ **/
+const gchar *
+pk_progress_get_transaction_id (PkProgress *progress)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), NULL);
+	return progress->priv->transaction_id;
+}
+
 /**
  * pk_progress_set_percentage:
+ * @progress: a valid #PkProgress instance
  *
  * Since: 0.5.2
  **/
@@ -240,8 +282,22 @@ pk_progress_set_percentage (PkProgress *progress, gint percentage)
 	return TRUE;
 }
 
+/**
+ * pk_progress_get_percentage:
+ * @progress: a valid #PkProgress instance
+ *
+ * Since: 1.0.12
+ **/
+gint
+pk_progress_get_percentage (PkProgress *progress)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), -1);
+	return progress->priv->percentage;
+}
+
 /**
  * pk_progress_set_status:
+ * @progress: a valid #PkProgress instance
  *
  * Since: 0.5.2
  **/
@@ -261,8 +317,22 @@ pk_progress_set_status (PkProgress *progress, PkStatusEnum status)
 	return TRUE;
 }
 
+/**
+ * pk_progress_get_status:
+ * @progress: a valid #PkProgress instance
+ *
+ * Since: 1.0.12
+ **/
+PkStatusEnum
+pk_progress_get_status (PkProgress *progress)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), PK_STATUS_ENUM_UNKNOWN);
+	return progress->priv->status;
+}
+
 /**
  * pk_progress_set_role:
+ * @progress: a valid #PkProgress instance
  *
  * Since: 0.5.2
  **/
@@ -287,8 +357,22 @@ pk_progress_set_role (PkProgress *progress, PkRoleEnum role)
 	return TRUE;
 }
 
+/**
+ * pk_progress_get_role:
+ * @progress: a valid #PkProgress instance
+ *
+ * Since: 1.0.12
+ **/
+PkRoleEnum
+pk_progress_get_role (PkProgress *progress)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), PK_ROLE_ENUM_UNKNOWN);
+	return progress->priv->role;
+}
+
 /**
  * pk_progress_set_allow_cancel:
+ * @progress: a valid #PkProgress instance
  *
  * Since: 0.5.2
  **/
@@ -308,8 +392,22 @@ pk_progress_set_allow_cancel (PkProgress *progress, gboolean allow_cancel)
 	return TRUE;
 }
 
+/**
+ * pk_progress_get_allow_cancel:
+ * @progress: a valid #PkProgress instance
+ *
+ * Since: 1.0.12
+ **/
+gboolean
+pk_progress_get_allow_cancel (PkProgress *progress)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), FALSE);
+	return progress->priv->allow_cancel;
+}
+
 /**
  * pk_progress_set_caller_active:
+ * @progress: a valid #PkProgress instance
  *
  * Since: 0.5.2
  **/
@@ -329,8 +427,22 @@ pk_progress_set_caller_active (PkProgress *progress, gboolean caller_active)
 	return TRUE;
 }
 
+/**
+ * pk_progress_get_caller_active:
+ * @progress: a valid #PkProgress instance
+ *
+ * Since: 1.0.12
+ **/
+gboolean
+pk_progress_get_caller_active (PkProgress *progress)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), FALSE);
+	return progress->priv->caller_active;
+}
+
 /**
  * pk_progress_set_elapsed_time:
+ * @progress: a valid #PkProgress instance
  *
  * Since: 0.5.2
  **/
@@ -350,8 +462,22 @@ pk_progress_set_elapsed_time (PkProgress *progress, guint elapsed_time)
 	return TRUE;
 }
 
+/**
+ * pk_progress_get_elapsed_time:
+ * @progress: a valid #PkProgress instance
+ *
+ * Since: 1.0.12
+ **/
+guint
+pk_progress_get_elapsed_time (PkProgress *progress)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), 0);
+	return progress->priv->elapsed_time;
+}
+
 /**
  * pk_progress_set_remaining_time:
+ * @progress: a valid #PkProgress instance
  *
  * Since: 0.5.2
  **/
@@ -371,8 +497,22 @@ pk_progress_set_remaining_time (PkProgress *progress, guint remaining_time)
 	return TRUE;
 }
 
+/**
+ * pk_progress_get_remaining_time:
+ * @progress: a valid #PkProgress instance
+ *
+ * Since: 1.0.12
+ **/
+guint
+pk_progress_get_remaining_time (PkProgress *progress)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), 0);
+	return progress->priv->remaining_time;
+}
+
 /**
  * pk_progress_set_speed:
+ * @progress: a valid #PkProgress instance
  *
  * Since: 0.5.2
  **/
@@ -392,8 +532,22 @@ pk_progress_set_speed (PkProgress *progress, guint speed)
 	return TRUE;
 }
 
+/**
+ * pk_progress_get_speed:
+ * @progress: a valid #PkProgress instance
+ *
+ * Since: 1.0.12
+ **/
+guint
+pk_progress_get_speed (PkProgress *progress)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), 0);
+	return progress->priv->speed;
+}
+
 /**
  * pk_progress_set_download_size_remaining:
+ * @progress: a valid #PkProgress instance
  *
  * Since: 0.8.0
  **/
@@ -413,8 +567,22 @@ pk_progress_set_download_size_remaining (PkProgress *progress, guint64 download_
 	return TRUE;
 }
 
+/**
+ * pk_progress_get_download_size_remaining:
+ * @progress: a valid #PkProgress instance
+ *
+ * Since: 1.0.12
+ **/
+guint64
+pk_progress_get_download_size_remaining (PkProgress *progress)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), 0);
+	return progress->priv->download_size_remaining;
+}
+
 /**
  * pk_progress_set_transaction_flags:
+ * @progress: a valid #PkProgress instance
  *
  * Since: 0.8.8
  **/
@@ -434,8 +602,22 @@ pk_progress_set_transaction_flags (PkProgress *progress, guint64 transaction_fla
 	return TRUE;
 }
 
+/**
+ * pk_progress_get_transaction_flags:
+ * @progress: a valid #PkProgress instance
+ *
+ * Since: 1.0.12
+ **/
+guint64
+pk_progress_get_transaction_flags (PkProgress *progress)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), 0);
+	return progress->priv->transaction_flags;
+}
+
 /**
  * pk_progress_set_uid:
+ * @progress: a valid #PkProgress instance
  *
  * Since: 0.5.2
  **/
@@ -455,8 +637,22 @@ pk_progress_set_uid (PkProgress *progress, guint uid)
 	return TRUE;
 }
 
+/**
+ * pk_progress_get_uid:
+ * @progress: a valid #PkProgress instance
+ *
+ * Since: 1.0.12
+ **/
+guint
+pk_progress_get_uid (PkProgress *progress)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), 0);
+	return progress->priv->uid;
+}
+
 /**
  * pk_progress_set_package:
+ * @progress: a valid #PkProgress instance
  *
  * Since: 0.5.2
  **/
@@ -478,6 +674,21 @@ pk_progress_set_package (PkProgress *progress, PkPackage *package)
 	return TRUE;
 }
 
+/**
+ * pk_progress_get_package:
+ * @progress: a valid #PkProgress instance
+ *
+ * Return value: (transfer none):
+ *
+ * Since: 1.0.12
+ **/
+PkPackage *
+pk_progress_get_package (PkProgress *progress)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), NULL);
+	return progress->priv->package;
+}
+
 /**
  * pk_progress_set_property:
  **/
@@ -651,9 +862,9 @@ pk_progress_class_init (PkProgressClass *klass)
 	 *
 	 * Since: 0.8.0
 	 */
-	pspec = g_param_spec_uint ("download-size-remaining", NULL, NULL,
-				   0, G_MAXUINT, 0,
-				   G_PARAM_READWRITE);
+	pspec = g_param_spec_uint64 ("download-size-remaining", NULL, NULL,
+				     0, G_MAXUINT64, 0,
+				     G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_DOWNLOAD_SIZE_REMAINING, pspec);
 
 	/**
@@ -687,7 +898,7 @@ pk_progress_class_init (PkProgressClass *klass)
 	g_object_class_install_property (object_class, PROP_PACKAGE, pspec);
 
 	/**
-	 * PkProgress:item-progress-id:
+	 * PkProgress:item-progress:
 	 *
 	 * Since: 0.8.1
 	 */
