@@ -57,6 +57,10 @@ typedef struct _PkResultsPrivate	PkResultsPrivate;
 typedef struct _PkResults		PkResults;
 typedef struct _PkResultsClass		PkResultsClass;
 
+#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PkResults, g_object_unref)
+#endif
+
 struct _PkResults
 {
 	 GObject		 parent;
@@ -131,8 +135,6 @@ GPtrArray	*pk_results_get_repo_signature_required_array (PkResults	*results);
 GPtrArray	*pk_results_get_eula_required_array	(PkResults		*results);
 GPtrArray	*pk_results_get_media_change_required_array (PkResults		*results);
 GPtrArray	*pk_results_get_repo_detail_array	(PkResults		*results);
-G_DEPRECATED
-GPtrArray	*pk_results_get_message_array		(PkResults		*results);
 
 G_END_DECLS
 
